# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.inventory.v1 import savings_azure_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2


class SavingsAzureStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create_recommendation = channel.unary_unary(
                '/spaceone.api.inventory.v1.SavingsAzure/create_recommendation',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsCollectRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.create_inventory = channel.unary_unary(
                '/spaceone.api.inventory.v1.SavingsAzure/create_inventory',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsCollectRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.create_summary = channel.unary_unary(
                '/spaceone.api.inventory.v1.SavingsAzure/create_summary',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsSummaryRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get_coverage_ratio = channel.unary_unary(
                '/spaceone.api.inventory.v1.SavingsAzure/get_coverage_ratio',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.GetCoverageQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class SavingsAzureServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create_recommendation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create_inventory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create_summary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_coverage_ratio(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SavingsAzureServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create_recommendation': grpc.unary_unary_rpc_method_handler(
                    servicer.create_recommendation,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsCollectRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'create_inventory': grpc.unary_unary_rpc_method_handler(
                    servicer.create_inventory,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsCollectRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'create_summary': grpc.unary_unary_rpc_method_handler(
                    servicer.create_summary,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsSummaryRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get_coverage_ratio': grpc.unary_unary_rpc_method_handler(
                    servicer.get_coverage_ratio,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.GetCoverageQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.v1.SavingsAzure', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SavingsAzure(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create_recommendation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.SavingsAzure/create_recommendation',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsCollectRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def create_inventory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.SavingsAzure/create_inventory',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsCollectRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def create_summary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.SavingsAzure/create_summary',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.SavingsSummaryRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_coverage_ratio(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.SavingsAzure/get_coverage_ratio',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__azure__pb2.GetCoverageQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/monthly_exchange_rate.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9spaceone/api/cost_analysis/v1/monthly_exchange_rate.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"O\n\x1dSetMonthlyExchangeRateRequest\x12\r\n\x05month\x18\x01 \x01(\t\x12\x0c\n\x04rate\x18\x02 \x01(\x02\x12\x11\n\tdomain_id\x18\x03 \x01(\t\">\n\x1aMonthlyExchangeRateRequest\x12\r\n\x05month\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"Y\n\x18MonthlyExchangeRateQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"J\n\x17MonthlyExchangeRateInfo\x12\r\n\x05month\x18\x01 \x01(\t\x12\x0c\n\x04rate\x18\x02 \x01(\x02\x12\x12\n\ncreated_at\x18\x0b \x01(\t\"x\n\x18MonthlyExchangeRatesInfo\x12G\n\x07results\x18\x01 \x03(\x0b\x32\x36.spaceone.api.cost_analysis.v1.MonthlyExchangeRateInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\x93\x04\n\x13MonthlyExchangeRate\x12\x80\x01\n\x06\x63reate\x12<.spaceone.api.cost_analysis.v1.SetMonthlyExchangeRateRequest\x1a\x36.spaceone.api.cost_analysis.v1.MonthlyExchangeRateInfo\"\x00\x12\x80\x01\n\x06update\x12<.spaceone.api.cost_analysis.v1.SetMonthlyExchangeRateRequest\x1a\x36.spaceone.api.cost_analysis.v1.MonthlyExchangeRateInfo\"\x00\x12z\n\x03get\x12\x39.spaceone.api.cost_analysis.v1.MonthlyExchangeRateRequest\x1a\x36.spaceone.api.cost_analysis.v1.MonthlyExchangeRateInfo\"\x00\x12z\n\x04list\x12\x37.spaceone.api.cost_analysis.v1.MonthlyExchangeRateQuery\x1a\x37.spaceone.api.cost_analysis.v1.MonthlyExchangeRatesInfo\"\x00\x62\x06proto3')



_SETMONTHLYEXCHANGERATEREQUEST = DESCRIPTOR.message_types_by_name['SetMonthlyExchangeRateRequest']
_MONTHLYEXCHANGERATEREQUEST = DESCRIPTOR.message_types_by_name['MonthlyExchangeRateRequest']
_MONTHLYEXCHANGERATEQUERY = DESCRIPTOR.message_types_by_name['MonthlyExchangeRateQuery']
_MONTHLYEXCHANGERATEINFO = DESCRIPTOR.message_types_by_name['MonthlyExchangeRateInfo']
_MONTHLYEXCHANGERATESINFO = DESCRIPTOR.message_types_by_name['MonthlyExchangeRatesInfo']
SetMonthlyExchangeRateRequest = _reflection.GeneratedProtocolMessageType('SetMonthlyExchangeRateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMONTHLYEXCHANGERATEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.monthly_exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.SetMonthlyExchangeRateRequest)
  })
_sym_db.RegisterMessage(SetMonthlyExchangeRateRequest)

MonthlyExchangeRateRequest = _reflection.GeneratedProtocolMessageType('MonthlyExchangeRateRequest', (_message.Message,), {
  'DESCRIPTOR' : _MONTHLYEXCHANGERATEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.monthly_exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.MonthlyExchangeRateRequest)
  })
_sym_db.RegisterMessage(MonthlyExchangeRateRequest)

MonthlyExchangeRateQuery = _reflection.GeneratedProtocolMessageType('MonthlyExchangeRateQuery', (_message.Message,), {
  'DESCRIPTOR' : _MONTHLYEXCHANGERATEQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.monthly_exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.MonthlyExchangeRateQuery)
  })
_sym_db.RegisterMessage(MonthlyExchangeRateQuery)

MonthlyExchangeRateInfo = _reflection.GeneratedProtocolMessageType('MonthlyExchangeRateInfo', (_message.Message,), {
  'DESCRIPTOR' : _MONTHLYEXCHANGERATEINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.monthly_exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.MonthlyExchangeRateInfo)
  })
_sym_db.RegisterMessage(MonthlyExchangeRateInfo)

MonthlyExchangeRatesInfo = _reflection.GeneratedProtocolMessageType('MonthlyExchangeRatesInfo', (_message.Message,), {
  'DESCRIPTOR' : _MONTHLYEXCHANGERATESINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.monthly_exchange_rate_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.MonthlyExchangeRatesInfo)
  })
_sym_db.RegisterMessage(MonthlyExchangeRatesInfo)

_MONTHLYEXCHANGERATE = DESCRIPTOR.services_by_name['MonthlyExchangeRate']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SETMONTHLYEXCHANGERATEREQUEST._serialized_start=156
  _SETMONTHLYEXCHANGERATEREQUEST._serialized_end=235
  _MONTHLYEXCHANGERATEREQUEST._serialized_start=237
  _MONTHLYEXCHANGERATEREQUEST._serialized_end=299
  _MONTHLYEXCHANGERATEQUERY._serialized_start=301
  _MONTHLYEXCHANGERATEQUERY._serialized_end=390
  _MONTHLYEXCHANGERATEINFO._serialized_start=392
  _MONTHLYEXCHANGERATEINFO._serialized_end=466
  _MONTHLYEXCHANGERATESINFO._serialized_start=468
  _MONTHLYEXCHANGERATESINFO._serialized_end=588
  _MONTHLYEXCHANGERATE._serialized_start=591
  _MONTHLYEXCHANGERATE._serialized_end=1122
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/collector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)spaceone/api/inventory/v1/collector.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xd7\x02\n\nPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tsecret_id\x18\x04 \x01(\t\x12\x17\n\x0fsecret_group_id\x18\x05 \x01(\t\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12)\n\x08metadata\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12G\n\x0cupgrade_mode\x18\x0b \x01(\x0e\x32\x31.spaceone.api.inventory.v1.PluginInfo.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\"\xd5\x01\n\x16\x43reateCollectorRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12:\n\x0bplugin_info\x18\x02 \x01(\x0b\x32%.spaceone.api.inventory.v1.PluginInfo\x12\x10\n\x08priority\x18\x03 \x01(\x05\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x11\n\tis_public\x18\n \x01(\x08\x12\x12\n\nproject_id\x18\x0b \x01(\t\"\xc4\x01\n\x16UpdateCollectorRequest\x12\x14\n\x0c\x63ollector_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12:\n\x0bplugin_info\x18\x03 \x01(\x0b\x32%.spaceone.api.inventory.v1.PluginInfo\x12\x10\n\x08priority\x18\x04 \x01(\x05\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"\xfa\x01\n\x13UpdatePluginRequest\x12\x14\n\x0c\x63ollector_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\x12P\n\x0cupgrade_mode\x18\x05 \x01(\x0e\x32:.spaceone.api.inventory.v1.UpdatePluginRequest.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\";\n\x10\x43ollectorRequest\x12\x14\n\x0c\x63ollector_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"L\n\x13GetCollectorRequest\x12\x14\n\x0c\x63ollector_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x86\x02\n\x0e\x43ollectorQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x14\n\x0c\x63ollector_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12>\n\x05state\x18\x04 \x01(\x0e\x32/.spaceone.api.inventory.v1.CollectorQuery.State\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12\x11\n\tplugin_id\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x07 \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\x9e\x01\n\x0e\x43ollectRequest\x12\x14\n\x0c\x63ollector_id\x18\x01 \x01(\t\x12\'\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tsecret_id\x18\x03 \x01(\t\x12\x14\n\x0c\x63ollect_mode\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12\x11\n\tuse_cache\x18\x06 \x01(\x08\"Q\n\x13VerifyPluginRequest\x12\x14\n\x0c\x63ollector_id\x18\x01 \x01(\t\x12\x11\n\tsecret_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"\xbd\x03\n\rCollectorInfo\x12\x14\n\x0c\x63ollector_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12=\n\x05state\x18\x03 \x01(\x0e\x32..spaceone.api.inventory.v1.CollectorInfo.State\x12:\n\x0bplugin_info\x18\x04 \x01(\x0b\x32%.spaceone.api.inventory.v1.PluginInfo\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x08 \x01(\t\x12\x19\n\x11last_collected_at\x18\t \x01(\t\x12\x11\n\tdomain_id\x18\n \x01(\t\x12\x10\n\x08provider\x18\x0b \x01(\t\x12+\n\ncapability\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tis_public\x18\x14 \x01(\x08\x12\x12\n\nproject_id\x18\x15 \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"`\n\x0e\x43ollectorsInfo\x12\x39\n\x07results\x18\x01 \x03(\x0b\x32(.spaceone.api.inventory.v1.CollectorInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"]\n\x12\x43ollectorStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x1c\n\nVerifyInfo\x12\x0e\n\x06status\x18\x01 \x01(\x08\"]\n\tErrorInfo\x12\x12\n\nerror_code\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12+\n\nadditional\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xeb\x03\n\x07JobInfo\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x39\n\x06status\x18\x02 \x01(\x0e\x32).spaceone.api.inventory.v1.JobInfo.Status\x12\'\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0btotal_tasks\x18\x04 \x01(\x05\x12\x16\n\x0eremained_tasks\x18\x05 \x01(\x05\x12\x34\n\x06\x65rrors\x18\x06 \x03(\x0b\x32$.spaceone.api.inventory.v1.ErrorInfo\x12@\n\x0e\x63ollector_info\x18\x0b \x01(\x0b\x32(.spaceone.api.inventory.v1.CollectorInfo\x12\x12\n\nproject_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x12\n\nupdated_at\x18\x16 \x01(\t\x12\x13\n\x0b\x66inished_at\x18\x17 \x01(\t\"c\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0c\n\x08\x43\x41NCELED\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\x12\x0b\n\x07SUCCESS\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\x0b\n\x07TIMEOUT\x10\x06\"K\n\tScheduled\x12\x0c\n\x04\x63ron\x18\x01 \x01(\t\x12\x10\n\x08interval\x18\x02 \x01(\x05\x12\x0f\n\x07minutes\x18\x03 \x03(\x05\x12\r\n\x05hours\x18\x04 \x03(\x05\"\xc5\x01\n\x15\x43reateScheduleRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63ollector_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0c\x63ollect_mode\x18\x04 \x01(\t\x12\x36\n\x08schedule\x18\x05 \x01(\x0b\x32$.spaceone.api.inventory.v1.Scheduled\x12\'\n\x06\x66ilter\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xda\x01\n\x15UpdateScheduleRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x13\n\x0bschedule_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ollector_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x14\n\x0c\x63ollect_mode\x18\x05 \x01(\t\x12\x36\n\x08schedule\x18\x06 \x01(\x0b\x32$.spaceone.api.inventory.v1.Scheduled\x12\'\n\x06\x66ilter\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\"O\n\x0fScheduleRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x13\n\x0bschedule_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ollector_id\x18\x03 \x01(\t\"U\n\x15\x44\x65leteScheduleRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x13\n\x0bschedule_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63ollector_id\x18\x03 \x01(\t\"y\n\rScheduleQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x14\n\x0c\x63ollector_id\x18\x02 \x01(\t\x12\x13\n\x0bschedule_id\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\xac\x02\n\x0cScheduleInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x13\n\x0bschedule_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0c\x63ollect_mode\x18\x04 \x01(\t\x12\x36\n\x08schedule\x18\x05 \x01(\x0b\x32$.spaceone.api.inventory.v1.Scheduled\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x19\n\x11last_scheduled_at\x18\x0b \x01(\t\x12@\n\x0e\x63ollector_info\x18\x14 \x01(\x0b\x32(.spaceone.api.inventory.v1.CollectorInfo\x12\'\n\x06\x66ilter\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\"^\n\rSchedulesInfo\x12\x38\n\x07results\x18\x01 \x03(\x0b\x32\'.spaceone.api.inventory.v1.ScheduleInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xe4\x13\n\tCollector\x12\x87\x01\n\x06\x63reate\x12\x31.spaceone.api.inventory.v1.CreateCollectorRequest\x1a(.spaceone.api.inventory.v1.CollectorInfo\" \x82\xd3\xe4\x93\x02\x1a\"\x18/inventory/v1/collectors\x12\x95\x01\n\x06update\x12\x31.spaceone.api.inventory.v1.UpdateCollectorRequest\x1a(.spaceone.api.inventory.v1.CollectorInfo\".\x82\xd3\xe4\x93\x02(\x1a&/inventory/v1/collector/{collector_id}\x12\xa0\x01\n\rupdate_plugin\x12..spaceone.api.inventory.v1.UpdatePluginRequest\x1a(.spaceone.api.inventory.v1.CollectorInfo\"5\x82\xd3\xe4\x93\x02/\x1a-/inventory/v1/collector/{collector_id}/plugin\x12\x95\x01\n\rverify_plugin\x12..spaceone.api.inventory.v1.VerifyPluginRequest\x1a\x16.google.protobuf.Empty\"<\x82\xd3\xe4\x93\x02\x36\"4/inventory/v1/collector/{collector_id}/plugin/verify\x12}\n\x06\x64\x65lete\x12+.spaceone.api.inventory.v1.CollectorRequest\x1a\x16.google.protobuf.Empty\".\x82\xd3\xe4\x93\x02(*&/inventory/v1/collector/{collector_id}\x12\x8f\x01\n\x03get\x12..spaceone.api.inventory.v1.GetCollectorRequest\x1a(.spaceone.api.inventory.v1.CollectorInfo\".\x82\xd3\xe4\x93\x02(\x12&/inventory/v1/collector/{collector_id}\x12\x96\x01\n\x06\x65nable\x12+.spaceone.api.inventory.v1.CollectorRequest\x1a(.spaceone.api.inventory.v1.CollectorInfo\"5\x82\xd3\xe4\x93\x02/\x1a-/inventory/v1/collector/{collector_id}/enable\x12\x98\x01\n\x07\x64isable\x12+.spaceone.api.inventory.v1.CollectorRequest\x1a(.spaceone.api.inventory.v1.CollectorInfo\"6\x82\xd3\xe4\x93\x02\x30\x1a./inventory/v1/collector/{collector_id}/disable\x12\xa1\x01\n\x04list\x12).spaceone.api.inventory.v1.CollectorQuery\x1a).spaceone.api.inventory.v1.CollectorsInfo\"C\x82\xd3\xe4\x93\x02=\x12\x18/inventory/v1/collectorsZ!\"\x1f/inventory/v1/collectors/search\x12u\n\x04stat\x12-.spaceone.api.inventory.v1.CollectorStatQuery\x1a\x17.google.protobuf.Struct\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/inventory/v1/collectors/stat\x12\x90\x01\n\x07\x63ollect\x12).spaceone.api.inventory.v1.CollectRequest\x1a\".spaceone.api.inventory.v1.JobInfo\"6\x82\xd3\xe4\x93\x02\x30\"./inventory/v1/collector/{collector_id}/collect\x12\xa2\x01\n\x0c\x61\x64\x64_schedule\x12\x30.spaceone.api.inventory.v1.CreateScheduleRequest\x1a\'.spaceone.api.inventory.v1.ScheduleInfo\"7\x82\xd3\xe4\x93\x02\x31\"//inventory/v1/collector/{collector_id}/schedule\x12\xaa\x01\n\x0cget_schedule\x12*.spaceone.api.inventory.v1.ScheduleRequest\x1a\'.spaceone.api.inventory.v1.ScheduleInfo\"E\x82\xd3\xe4\x93\x02?\x12=/inventory/v1/collector/{collector_id}/schedule/{schedule_id}\x12\xb3\x01\n\x0fupdate_schedule\x12\x30.spaceone.api.inventory.v1.UpdateScheduleRequest\x1a\'.spaceone.api.inventory.v1.ScheduleInfo\"E\x82\xd3\xe4\x93\x02?\"=/inventory/v1/collector/{collector_id}/schedule/{schedule_id}\x12\xa2\x01\n\x0f\x64\x65lete_schedule\x12\x30.spaceone.api.inventory.v1.DeleteScheduleRequest\x1a\x16.google.protobuf.Empty\"E\x82\xd3\xe4\x93\x02?*=/inventory/v1/collector/{collector_id}/schedule/{schedule_id}\x12\xd9\x01\n\x0elist_schedules\x12(.spaceone.api.inventory.v1.ScheduleQuery\x1a(.spaceone.api.inventory.v1.SchedulesInfo\"s\x82\xd3\xe4\x93\x02m\x12\x30/inventory/v1/collector/{collector_id}/schedulesZ9\"7/inventory/v1/collector/{collector_id}/schedules/searchb\x06proto3')



_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_CREATECOLLECTORREQUEST = DESCRIPTOR.message_types_by_name['CreateCollectorRequest']
_UPDATECOLLECTORREQUEST = DESCRIPTOR.message_types_by_name['UpdateCollectorRequest']
_UPDATEPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdatePluginRequest']
_COLLECTORREQUEST = DESCRIPTOR.message_types_by_name['CollectorRequest']
_GETCOLLECTORREQUEST = DESCRIPTOR.message_types_by_name['GetCollectorRequest']
_COLLECTORQUERY = DESCRIPTOR.message_types_by_name['CollectorQuery']
_COLLECTREQUEST = DESCRIPTOR.message_types_by_name['CollectRequest']
_VERIFYPLUGINREQUEST = DESCRIPTOR.message_types_by_name['VerifyPluginRequest']
_COLLECTORINFO = DESCRIPTOR.message_types_by_name['CollectorInfo']
_COLLECTORSINFO = DESCRIPTOR.message_types_by_name['CollectorsInfo']
_COLLECTORSTATQUERY = DESCRIPTOR.message_types_by_name['CollectorStatQuery']
_VERIFYINFO = DESCRIPTOR.message_types_by_name['VerifyInfo']
_ERRORINFO = DESCRIPTOR.message_types_by_name['ErrorInfo']
_JOBINFO = DESCRIPTOR.message_types_by_name['JobInfo']
_SCHEDULED = DESCRIPTOR.message_types_by_name['Scheduled']
_CREATESCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['CreateScheduleRequest']
_UPDATESCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['UpdateScheduleRequest']
_SCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['ScheduleRequest']
_DELETESCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['DeleteScheduleRequest']
_SCHEDULEQUERY = DESCRIPTOR.message_types_by_name['ScheduleQuery']
_SCHEDULEINFO = DESCRIPTOR.message_types_by_name['ScheduleInfo']
_SCHEDULESINFO = DESCRIPTOR.message_types_by_name['SchedulesInfo']
_PLUGININFO_UPGRADEMODE = _PLUGININFO.enum_types_by_name['UpgradeMode']
_UPDATEPLUGINREQUEST_UPGRADEMODE = _UPDATEPLUGINREQUEST.enum_types_by_name['UpgradeMode']
_COLLECTORQUERY_STATE = _COLLECTORQUERY.enum_types_by_name['State']
_COLLECTORINFO_STATE = _COLLECTORINFO.enum_types_by_name['State']
_JOBINFO_STATUS = _JOBINFO.enum_types_by_name['Status']
PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

CreateCollectorRequest = _reflection.GeneratedProtocolMessageType('CreateCollectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOLLECTORREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateCollectorRequest)
  })
_sym_db.RegisterMessage(CreateCollectorRequest)

UpdateCollectorRequest = _reflection.GeneratedProtocolMessageType('UpdateCollectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOLLECTORREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateCollectorRequest)
  })
_sym_db.RegisterMessage(UpdateCollectorRequest)

UpdatePluginRequest = _reflection.GeneratedProtocolMessageType('UpdatePluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPLUGINREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdatePluginRequest)
  })
_sym_db.RegisterMessage(UpdatePluginRequest)

CollectorRequest = _reflection.GeneratedProtocolMessageType('CollectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTORREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CollectorRequest)
  })
_sym_db.RegisterMessage(CollectorRequest)

GetCollectorRequest = _reflection.GeneratedProtocolMessageType('GetCollectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOLLECTORREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetCollectorRequest)
  })
_sym_db.RegisterMessage(GetCollectorRequest)

CollectorQuery = _reflection.GeneratedProtocolMessageType('CollectorQuery', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTORQUERY,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CollectorQuery)
  })
_sym_db.RegisterMessage(CollectorQuery)

CollectRequest = _reflection.GeneratedProtocolMessageType('CollectRequest', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CollectRequest)
  })
_sym_db.RegisterMessage(CollectRequest)

VerifyPluginRequest = _reflection.GeneratedProtocolMessageType('VerifyPluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYPLUGINREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.VerifyPluginRequest)
  })
_sym_db.RegisterMessage(VerifyPluginRequest)

CollectorInfo = _reflection.GeneratedProtocolMessageType('CollectorInfo', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTORINFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CollectorInfo)
  })
_sym_db.RegisterMessage(CollectorInfo)

CollectorsInfo = _reflection.GeneratedProtocolMessageType('CollectorsInfo', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTORSINFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CollectorsInfo)
  })
_sym_db.RegisterMessage(CollectorsInfo)

CollectorStatQuery = _reflection.GeneratedProtocolMessageType('CollectorStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTORSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CollectorStatQuery)
  })
_sym_db.RegisterMessage(CollectorStatQuery)

VerifyInfo = _reflection.GeneratedProtocolMessageType('VerifyInfo', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYINFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.VerifyInfo)
  })
_sym_db.RegisterMessage(VerifyInfo)

ErrorInfo = _reflection.GeneratedProtocolMessageType('ErrorInfo', (_message.Message,), {
  'DESCRIPTOR' : _ERRORINFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ErrorInfo)
  })
_sym_db.RegisterMessage(ErrorInfo)

JobInfo = _reflection.GeneratedProtocolMessageType('JobInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBINFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobInfo)
  })
_sym_db.RegisterMessage(JobInfo)

Scheduled = _reflection.GeneratedProtocolMessageType('Scheduled', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULED,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.Scheduled)
  })
_sym_db.RegisterMessage(Scheduled)

CreateScheduleRequest = _reflection.GeneratedProtocolMessageType('CreateScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCHEDULEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateScheduleRequest)
  })
_sym_db.RegisterMessage(CreateScheduleRequest)

UpdateScheduleRequest = _reflection.GeneratedProtocolMessageType('UpdateScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCHEDULEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateScheduleRequest)
  })
_sym_db.RegisterMessage(UpdateScheduleRequest)

ScheduleRequest = _reflection.GeneratedProtocolMessageType('ScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ScheduleRequest)
  })
_sym_db.RegisterMessage(ScheduleRequest)

DeleteScheduleRequest = _reflection.GeneratedProtocolMessageType('DeleteScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCHEDULEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.DeleteScheduleRequest)
  })
_sym_db.RegisterMessage(DeleteScheduleRequest)

ScheduleQuery = _reflection.GeneratedProtocolMessageType('ScheduleQuery', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ScheduleQuery)
  })
_sym_db.RegisterMessage(ScheduleQuery)

ScheduleInfo = _reflection.GeneratedProtocolMessageType('ScheduleInfo', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEINFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ScheduleInfo)
  })
_sym_db.RegisterMessage(ScheduleInfo)

SchedulesInfo = _reflection.GeneratedProtocolMessageType('SchedulesInfo', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULESINFO,
  '__module__' : 'spaceone.api.inventory.v1.collector_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.SchedulesInfo)
  })
_sym_db.RegisterMessage(SchedulesInfo)

_COLLECTOR = DESCRIPTOR.services_by_name['Collector']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COLLECTOR.methods_by_name['create']._options = None
  _COLLECTOR.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\032\"\030/inventory/v1/collectors'
  _COLLECTOR.methods_by_name['update']._options = None
  _COLLECTOR.methods_by_name['update']._serialized_options = b'\202\323\344\223\002(\032&/inventory/v1/collector/{collector_id}'
  _COLLECTOR.methods_by_name['update_plugin']._options = None
  _COLLECTOR.methods_by_name['update_plugin']._serialized_options = b'\202\323\344\223\002/\032-/inventory/v1/collector/{collector_id}/plugin'
  _COLLECTOR.methods_by_name['verify_plugin']._options = None
  _COLLECTOR.methods_by_name['verify_plugin']._serialized_options = b'\202\323\344\223\0026\"4/inventory/v1/collector/{collector_id}/plugin/verify'
  _COLLECTOR.methods_by_name['delete']._options = None
  _COLLECTOR.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002(*&/inventory/v1/collector/{collector_id}'
  _COLLECTOR.methods_by_name['get']._options = None
  _COLLECTOR.methods_by_name['get']._serialized_options = b'\202\323\344\223\002(\022&/inventory/v1/collector/{collector_id}'
  _COLLECTOR.methods_by_name['enable']._options = None
  _COLLECTOR.methods_by_name['enable']._serialized_options = b'\202\323\344\223\002/\032-/inventory/v1/collector/{collector_id}/enable'
  _COLLECTOR.methods_by_name['disable']._options = None
  _COLLECTOR.methods_by_name['disable']._serialized_options = b'\202\323\344\223\0020\032./inventory/v1/collector/{collector_id}/disable'
  _COLLECTOR.methods_by_name['list']._options = None
  _COLLECTOR.methods_by_name['list']._serialized_options = b'\202\323\344\223\002=\022\030/inventory/v1/collectorsZ!\"\037/inventory/v1/collectors/search'
  _COLLECTOR.methods_by_name['stat']._options = None
  _COLLECTOR.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\037\"\035/inventory/v1/collectors/stat'
  _COLLECTOR.methods_by_name['collect']._options = None
  _COLLECTOR.methods_by_name['collect']._serialized_options = b'\202\323\344\223\0020\"./inventory/v1/collector/{collector_id}/collect'
  _COLLECTOR.methods_by_name['add_schedule']._options = None
  _COLLECTOR.methods_by_name['add_schedule']._serialized_options = b'\202\323\344\223\0021\"//inventory/v1/collector/{collector_id}/schedule'
  _COLLECTOR.methods_by_name['get_schedule']._options = None
  _COLLECTOR.methods_by_name['get_schedule']._serialized_options = b'\202\323\344\223\002?\022=/inventory/v1/collector/{collector_id}/schedule/{schedule_id}'
  _COLLECTOR.methods_by_name['update_schedule']._options = None
  _COLLECTOR.methods_by_name['update_schedule']._serialized_options = b'\202\323\344\223\002?\"=/inventory/v1/collector/{collector_id}/schedule/{schedule_id}'
  _COLLECTOR.methods_by_name['delete_schedule']._options = None
  _COLLECTOR.methods_by_name['delete_schedule']._serialized_options = b'\202\323\344\223\002?*=/inventory/v1/collector/{collector_id}/schedule/{schedule_id}'
  _COLLECTOR.methods_by_name['list_schedules']._options = None
  _COLLECTOR.methods_by_name['list_schedules']._serialized_options = b'\202\323\344\223\002m\0220/inventory/v1/collector/{collector_id}/schedulesZ9\"7/inventory/v1/collector/{collector_id}/schedules/search'
  _PLUGININFO._serialized_start=196
  _PLUGININFO._serialized_end=539
  _PLUGININFO_UPGRADEMODE._serialized_start=494
  _PLUGININFO_UPGRADEMODE._serialized_end=539
  _CREATECOLLECTORREQUEST._serialized_start=542
  _CREATECOLLECTORREQUEST._serialized_end=755
  _UPDATECOLLECTORREQUEST._serialized_start=758
  _UPDATECOLLECTORREQUEST._serialized_end=954
  _UPDATEPLUGINREQUEST._serialized_start=957
  _UPDATEPLUGINREQUEST._serialized_end=1207
  _UPDATEPLUGINREQUEST_UPGRADEMODE._serialized_start=494
  _UPDATEPLUGINREQUEST_UPGRADEMODE._serialized_end=539
  _COLLECTORREQUEST._serialized_start=1209
  _COLLECTORREQUEST._serialized_end=1268
  _GETCOLLECTORREQUEST._serialized_start=1270
  _GETCOLLECTORREQUEST._serialized_end=1346
  _COLLECTORQUERY._serialized_start=1349
  _COLLECTORQUERY._serialized_end=1611
  _COLLECTORQUERY_STATE._serialized_start=1567
  _COLLECTORQUERY_STATE._serialized_end=1611
  _COLLECTREQUEST._serialized_start=1614
  _COLLECTREQUEST._serialized_end=1772
  _VERIFYPLUGINREQUEST._serialized_start=1774
  _VERIFYPLUGINREQUEST._serialized_end=1855
  _COLLECTORINFO._serialized_start=1858
  _COLLECTORINFO._serialized_end=2303
  _COLLECTORINFO_STATE._serialized_start=1567
  _COLLECTORINFO_STATE._serialized_end=1611
  _COLLECTORSINFO._serialized_start=2305
  _COLLECTORSINFO._serialized_end=2401
  _COLLECTORSTATQUERY._serialized_start=2403
  _COLLECTORSTATQUERY._serialized_end=2496
  _VERIFYINFO._serialized_start=2498
  _VERIFYINFO._serialized_end=2526
  _ERRORINFO._serialized_start=2528
  _ERRORINFO._serialized_end=2621
  _JOBINFO._serialized_start=2624
  _JOBINFO._serialized_end=3115
  _JOBINFO_STATUS._serialized_start=3016
  _JOBINFO_STATUS._serialized_end=3115
  _SCHEDULED._serialized_start=3117
  _SCHEDULED._serialized_end=3192
  _CREATESCHEDULEREQUEST._serialized_start=3195
  _CREATESCHEDULEREQUEST._serialized_end=3392
  _UPDATESCHEDULEREQUEST._serialized_start=3395
  _UPDATESCHEDULEREQUEST._serialized_end=3613
  _SCHEDULEREQUEST._serialized_start=3615
  _SCHEDULEREQUEST._serialized_end=3694
  _DELETESCHEDULEREQUEST._serialized_start=3696
  _DELETESCHEDULEREQUEST._serialized_end=3781
  _SCHEDULEQUERY._serialized_start=3783
  _SCHEDULEQUERY._serialized_end=3904
  _SCHEDULEINFO._serialized_start=3907
  _SCHEDULEINFO._serialized_end=4207
  _SCHEDULESINFO._serialized_start=4209
  _SCHEDULESINFO._serialized_end=4303
  _COLLECTOR._serialized_start=4306
  _COLLECTOR._serialized_end=6838
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.monitoring.v1 import event_pb2 as spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2


class EventStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Event/create',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.CreateEventRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Event/get',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.GetEventRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.EventInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Event/list',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.EventQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.EventsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Event/stat',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.EventStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class EventServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Event. The Event creation process starts with validation checking whether the input data is from a webhook or not. After the input data is validated, the data is processed and used to create the Event.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Event matching the input parameters, `event_id` and `domain_id`. Prints detailed information about the Event.
        request_example: >-
        {
        "event_id": "event-4e16ba3bd384",
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "event_id": "event-4e16ba3bd384",
        "event_key": "cfbdd0cee08f0f2664dbef297c370017",
        "event_type": "ALERT",
        "title": "Notification of access to the SpaceONE bastion Host",
        "description": "SSH Access to stargate-dev-kubectl-amzl2 from spaceoneadm",
        "severity": "INFO",
        "resource": {
        "resource_id": "server-1187737cc0d9",
        "resource_type": "inventory.Server",
        "name": "stargate-dev-kubectl-amzl2"
        },
        "raw_data": {
        "resource": {
        "name": "stargate-dev-kubectl-amzl2",
        "resource_id": "server-1187737cc0d9",
        "resource_type": "inventory.Server"
        },
        "event_key": "cfbdd0cee08f0f2664dbef297c370017",
        "title": "Notification of access to the SpaceONE bastion Host",
        "severity": "INFO",
        "description": "SSH Access to stargate-dev-kubectl-amzl2 from spaceoneadm",
        "event_type": "ALERT",
        "additional_info": {
        "host": [],
        "user": "spaceoneadm"
        }
        },
        "additional_info": {
        "host": "[]",
        "user": "spaceoneadm"
        },
        "alert_id": "alert-06462f6cb54e",
        "webhook_id": "webhook-ff9e2eda678a",
        "project_id": "project-18655561c535",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-21T00:34:58.034Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Events. You must specify the `domain_id`. You can use a query to get a filtered list of Events.
        request_example: >-
        {
        "query": {},
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "results": [
        {
        "event_id": "event-4e16ba3bd384",
        "event_key": "cfbdd0cee08f0f2664dbef297c370017",
        "event_type": "ALERT",
        "title": "Notification of access to the SpaceONE bastion Host",
        "description": "SSH Access to stargate-dev-kubectl-amzl2 from spaceoneadm",
        "severity": "INFO",
        "resource": {
        "resource_id": "server-1187737cc0d9",
        "resource_type": "inventory.Server",
        "name": "stargate-dev-kubectl-amzl2"
        },
        "raw_data": {
        "resource": {
        "name": "stargate-dev-kubectl-amzl2",
        "resource_type": "inventory.Server",
        "resource_id": "server-1187737cc0d9"
        },
        "event_key": "cfbdd0cee08f0f2664dbef297c370017",
        "additional_info": {
        "user": "spaceoneadm",
        "host": []
        },
        "severity": "INFO",
        "description": "SSH Access to stargate-dev-kubectl-amzl2 from spaceoneadm",
        "title": "Notification of access to the SpaceONE bastion Host",
        "event_type": "ALERT"
        },
        "additional_info": {
        "user": "spaceoneadm",
        "host": "[]"
        },
        "alert_id": "alert-06462f6cb54e",
        "webhook_id": "webhook-ff9e2eda678a",
        "project_id": "project-18655561c535",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-21T00:34:58.034Z"
        },
        {
        "event_id": "event-b178e1b71daf",
        "event_key": "abc16e5455c26ab7611bf8aa8d1020cc",
        "event_type": "ALERT",
        "title": "Notification of access to the SpaceONE bastion Host",
        "description": "SSH Access to stargate-dev-kubectl-amzl2 from glee@mz.co.kr",
        "severity": "INFO",
        "resource": {
        "resource_id": "server-1187737cc0d9",
        "resource_type": "inventory.Server",
        "name": "stargate-dev-kubectl-amzl2"
        },
        "raw_data": {
        "additional_info": {
        "host": [
        "125.131.104.40"
        ],
        "user": "glee@mz.co.kr"
        },
        "description": "SSH Access to stargate-dev-kubectl-amzl2 from glee@mz.co.kr",
        "severity": "INFO",
        "event_type": "ALERT",
        "title": "Notification of access to the SpaceONE bastion Host",
        "resource": {
        "resource_type": "inventory.Server",
        "name": "stargate-dev-kubectl-amzl2",
        "resource_id": "server-1187737cc0d9"
        },
        "event_key": "abc16e5455c26ab7611bf8aa8d1020cc"
        },
        "additional_info": {
        "user": "glee@mz.co.kr",
        "host": "['125.131.104.40']"
        },
        "alert_id": "alert-332617cf2894",
        "webhook_id": "webhook-ff9e2eda678a",
        "project_id": "project-18655561c535",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-21T00:34:52.822Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.CreateEventRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.GetEventRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.EventInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.EventQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.EventsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.EventStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.monitoring.v1.Event', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Event(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Event/create',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.CreateEventRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Event/get',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.GetEventRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.EventInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Event/list',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.EventQuery.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.EventsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Event/stat',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_event__pb2.EventStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/stack_resource_history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9spaceone/api/provisioning/v1/stack_resource_history.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x99\x03\n\x19StackResourceHistoryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12!\n\x19stack_resource_history_id\x18\x03 \x01(\t\x12\x18\n\x10stack_history_id\x18\x04 \x01(\t\x12\x19\n\x11stack_resource_id\x18\x05 \x01(\t\x12\x15\n\rresource_name\x18\x06 \x01(\t\x12N\n\x06\x61\x63tion\x18\x07 \x01(\x0e\x32>.spaceone.api.provisioning.v1.StackResourceHistoryQuery.Action\x12\x12\n\ncreated_at\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\x12\x10\n\x08stack_id\x18\n \x01(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\"6\n\x06\x41\x63tion\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\"\xa9\x03\n\x18StackResourceHistoryInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12!\n\x19stack_resource_history_id\x18\x02 \x01(\t\x12\x18\n\x10stack_history_id\x18\x03 \x01(\t\x12\x19\n\x11stack_resource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12M\n\x06\x61\x63tion\x18\x06 \x01(\x0e\x32=.spaceone.api.provisioning.v1.StackResourceHistoryInfo.Action\x12(\n\x04\x64iff\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x12\n\ndiff_count\x18\x08 \x01(\x05\x12\x12\n\ncreated_at\x18\t \x01(\t\x12\x0c\n\x04type\x18\n \x01(\t\x12\x10\n\x08stack_id\x18\x0b \x01(\t\x12\x12\n\ncreated_by\x18\x0c \x01(\t\"6\n\x06\x41\x63tion\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\"z\n\x1aStackResourceHistoriesInfo\x12G\n\x07results\x18\x01 \x03(\x0b\x32\x36.spaceone.api.provisioning.v1.StackResourceHistoryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\x95\x01\n\x1dStackResourceHistoryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x19\n\x11stack_resource_id\x18\x03 \x01(\t\x12\x10\n\x08stack_id\x18\x04 \x01(\t2\x8d\x05\n\x14StackResourceHistory\x12\x8a\x02\n\x1cget_stack_resource_histories\x12\x37.spaceone.api.provisioning.v1.StackResourceHistoryQuery\x1a\x38.spaceone.api.provisioning.v1.StackResourceHistoriesInfo\"w\x82\xd3\xe4\x93\x02q\x12=/provisioning/v1/stack-resource/{stack_resource_id}/historiesZ0\"./provisioning/v1/stack-resource-history/search\x12\xd2\x01\n\x1aget_stack_resource_history\x12\x37.spaceone.api.provisioning.v1.StackResourceHistoryQuery\x1a\x36.spaceone.api.provisioning.v1.StackResourceHistoryInfo\"C\x82\xd3\xe4\x93\x02=\";/provisioning/v1/stack-resource/{stack_resource_id}/history\x12\x92\x01\n\x04stat\x12;.spaceone.api.provisioning.v1.StackResourceHistoryStatQuery\x1a\x17.google.protobuf.Struct\"4\x82\xd3\xe4\x93\x02.\",/provisioning/v1/stack-resource-history/statb\x06proto3')



_STACKRESOURCEHISTORYQUERY = DESCRIPTOR.message_types_by_name['StackResourceHistoryQuery']
_STACKRESOURCEHISTORYINFO = DESCRIPTOR.message_types_by_name['StackResourceHistoryInfo']
_STACKRESOURCEHISTORIESINFO = DESCRIPTOR.message_types_by_name['StackResourceHistoriesInfo']
_STACKRESOURCEHISTORYSTATQUERY = DESCRIPTOR.message_types_by_name['StackResourceHistoryStatQuery']
_STACKRESOURCEHISTORYQUERY_ACTION = _STACKRESOURCEHISTORYQUERY.enum_types_by_name['Action']
_STACKRESOURCEHISTORYINFO_ACTION = _STACKRESOURCEHISTORYINFO.enum_types_by_name['Action']
StackResourceHistoryQuery = _reflection.GeneratedProtocolMessageType('StackResourceHistoryQuery', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCEHISTORYQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceHistoryQuery)
  })
_sym_db.RegisterMessage(StackResourceHistoryQuery)

StackResourceHistoryInfo = _reflection.GeneratedProtocolMessageType('StackResourceHistoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCEHISTORYINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceHistoryInfo)
  })
_sym_db.RegisterMessage(StackResourceHistoryInfo)

StackResourceHistoriesInfo = _reflection.GeneratedProtocolMessageType('StackResourceHistoriesInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCEHISTORIESINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceHistoriesInfo)
  })
_sym_db.RegisterMessage(StackResourceHistoriesInfo)

StackResourceHistoryStatQuery = _reflection.GeneratedProtocolMessageType('StackResourceHistoryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCEHISTORYSTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceHistoryStatQuery)
  })
_sym_db.RegisterMessage(StackResourceHistoryStatQuery)

_STACKRESOURCEHISTORY = DESCRIPTOR.services_by_name['StackResourceHistory']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STACKRESOURCEHISTORY.methods_by_name['get_stack_resource_histories']._options = None
  _STACKRESOURCEHISTORY.methods_by_name['get_stack_resource_histories']._serialized_options = b'\202\323\344\223\002q\022=/provisioning/v1/stack-resource/{stack_resource_id}/historiesZ0\"./provisioning/v1/stack-resource-history/search'
  _STACKRESOURCEHISTORY.methods_by_name['get_stack_resource_history']._options = None
  _STACKRESOURCEHISTORY.methods_by_name['get_stack_resource_history']._serialized_options = b'\202\323\344\223\002=\";/provisioning/v1/stack-resource/{stack_resource_id}/history'
  _STACKRESOURCEHISTORY.methods_by_name['stat']._options = None
  _STACKRESOURCEHISTORY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002.\",/provisioning/v1/stack-resource-history/stat'
  _STACKRESOURCEHISTORYQUERY._serialized_start=186
  _STACKRESOURCEHISTORYQUERY._serialized_end=595
  _STACKRESOURCEHISTORYQUERY_ACTION._serialized_start=541
  _STACKRESOURCEHISTORYQUERY_ACTION._serialized_end=595
  _STACKRESOURCEHISTORYINFO._serialized_start=598
  _STACKRESOURCEHISTORYINFO._serialized_end=1023
  _STACKRESOURCEHISTORYINFO_ACTION._serialized_start=541
  _STACKRESOURCEHISTORYINFO_ACTION._serialized_end=595
  _STACKRESOURCEHISTORIESINFO._serialized_start=1025
  _STACKRESOURCEHISTORIESINFO._serialized_end=1147
  _STACKRESOURCEHISTORYSTATQUERY._serialized_start=1150
  _STACKRESOURCEHISTORYSTATQUERY._serialized_end=1299
  _STACKRESOURCEHISTORY._serialized_start=1302
  _STACKRESOURCEHISTORY._serialized_end=1955
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/stack.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.provisioning.v1 import stack_resource_pb2 as spaceone_dot_api_dot_provisioning_dot_v1_dot_stack__resource__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.identity.v1 import project_group_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_project__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(spaceone/api/provisioning/v1/stack.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x31spaceone/api/provisioning/v1/stack_resource.proto\x1a spaceone/api/core/v1/query.proto\x1a,spaceone/api/identity/v1/project_group.proto\"\xb5\x01\n\x13PublishStackRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08stack_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x0e\n\x06status\x18\x06 \x01(\t\x12\x13\n\x0bplan_status\x18\x07 \x01(\t\x12\x14\n\x0cpublish_type\x18\x08 \x01(\t\"\x8a\x02\n\x12\x43reateStackRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\nstack_name\x18\x02 \x01(\t\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x1a\n\x12service_account_id\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12-\n\x0c\x64iagram_info\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x42\n\tresources\x18\x08 \x03(\x0b\x32/.spaceone.api.provisioning.v1.StackResourceInfo\"3\n\x0cStackRequest\x12\x10\n\x08stack_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"X\n\x0fGetStackRequest\x12\x10\n\x08stack_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\x12\x12\n\nstack_type\x18\x04 \x01(\t\"\xbc\x03\n\x12UpdateStackRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08stack_id\x18\x02 \x01(\t\x12\x12\n\nstack_name\x18\x03 \x01(\t\x12\x12\n\ncatalog_id\x18\x04 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12-\n\x0c\x64iagram_info\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_by\x18\x08 \x01(\t\x12\x12\n\nupdated_by\x18\t \x01(\t\x12\x0e\n\x06status\x18\n \x01(\t\x12\x12\n\nproject_id\x18\x0b \x01(\t\x12\x1a\n\x12service_account_id\x18\x0c \x01(\t\x12\x10\n\x08provider\x18\r \x01(\t\x12\x13\n\x0bplan_status\x18\x0e \x01(\t\x12\x15\n\rstack_summary\x18\x0f \x01(\t\x12\x12\n\nstack_desc\x18\x10 \x01(\t\x12\x42\n\tresources\x18\x11 \x03(\x0b\x32/.spaceone.api.provisioning.v1.StackResourceInfo\"\x8b\x05\n\tStackInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08stack_id\x18\x02 \x01(\t\x12\x12\n\nstack_name\x18\x03 \x01(\t\x12\x12\n\ncatalog_id\x18\x04 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12-\n\x0c\x64iagram_info\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_by\x18\t \x01(\t\x12\x12\n\nupdated_by\x18\n \x01(\t\x12\x12\n\ncreated_at\x18\x0b \x01(\t\x12\x12\n\nupdated_at\x18\x0c \x01(\t\x12\x0e\n\x06status\x18\r \x01(\t\x12\x12\n\nproject_id\x18\x0e \x01(\t\x12\x1a\n\x12service_account_id\x18\x0f \x01(\t\x12\x10\n\x08provider\x18\x10 \x01(\t\x12\x13\n\x0bplan_status\x18\x11 \x01(\t\x12\x15\n\rstack_summary\x18\x12 \x01(\t\x12\x12\n\nstack_desc\x18\x13 \x01(\t\x12\x42\n\tresources\x18\x14 \x03(\x0b\x32/.spaceone.api.provisioning.v1.StackResourceInfo\x12\x13\n\x0b\x61pproved_at\x18\x15 \x01(\t\x12\x13\n\x0b\x61pproved_by\x18\x16 \x01(\t\x12\x18\n\x10project_group_id\x18\x17 \x01(\t\x12\x1a\n\x12project_group_name\x18\x18 \x01(\t\x12\x14\n\x0cproject_name\x18\x19 \x01(\t\x12\r\n\x05graph\x18\x1a \x01(\t\x12\x12\n\nstack_type\x18\x1b \x01(\t\x12\x15\n\rstack_temp_id\x18\x1c \x01(\t\"[\n\nStacksInfo\x12\x38\n\x07results\x18\x01 \x03(\x0b\x32\'.spaceone.api.provisioning.v1.StackInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\xa9\x01\n\nStackQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x10\n\x08stack_id\x18\x02 \x01(\t\x12\x12\n\nstack_name\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12\x12\n\nupdated_by\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x0e\n\x06status\x18\x07 \x01(\t\"Y\n\x0eStackStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xcc\x08\n\x05Stack\x12\x89\x01\n\x0c\x63reate_stack\x12\x30.spaceone.api.provisioning.v1.CreateStackRequest\x1a\'.spaceone.api.provisioning.v1.StackInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/provisioning/v1/stack\x12\xa3\x01\n\nget_stacks\x12(.spaceone.api.provisioning.v1.StackQuery\x1a(.spaceone.api.provisioning.v1.StacksInfo\"A\x82\xd3\xe4\x93\x02;\x12\x17/provisioning/v1/stacksZ \"\x1e/provisioning/v1/stacks/search\x12\x8e\x01\n\tget_stack\x12-.spaceone.api.provisioning.v1.GetStackRequest\x1a\'.spaceone.api.provisioning.v1.StackInfo\")\x82\xd3\xe4\x93\x02#\x12!/provisioning/v1/stack/{stack_id}\x12\x89\x01\n\x0cupdate_stack\x12\x30.spaceone.api.provisioning.v1.UpdateStackRequest\x1a\'.spaceone.api.provisioning.v1.StackInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\x1a\x16/provisioning/v1/stack\x12}\n\x0c\x64\x65lete_stack\x12*.spaceone.api.provisioning.v1.StackRequest\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#*!/provisioning/v1/stack/{stack_id}\x12\x82\x01\n\rpublish_stack\x12\x31.spaceone.api.provisioning.v1.PublishStackRequest\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 \"\x1e/provisioning/v1/stack/publish\x12r\n\x04stat\x12,.spaceone.api.provisioning.v1.StackStatQuery\x1a\x17.google.protobuf.Struct\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/provisioning/v1/stack/stat\x12|\n\nplan_stack\x12\x31.spaceone.api.provisioning.v1.PublishStackRequest\x1a\x16.google.protobuf.Empty\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/provisioning/v1/stack/planb\x06proto3')



_PUBLISHSTACKREQUEST = DESCRIPTOR.message_types_by_name['PublishStackRequest']
_CREATESTACKREQUEST = DESCRIPTOR.message_types_by_name['CreateStackRequest']
_STACKREQUEST = DESCRIPTOR.message_types_by_name['StackRequest']
_GETSTACKREQUEST = DESCRIPTOR.message_types_by_name['GetStackRequest']
_UPDATESTACKREQUEST = DESCRIPTOR.message_types_by_name['UpdateStackRequest']
_STACKINFO = DESCRIPTOR.message_types_by_name['StackInfo']
_STACKSINFO = DESCRIPTOR.message_types_by_name['StacksInfo']
_STACKQUERY = DESCRIPTOR.message_types_by_name['StackQuery']
_STACKSTATQUERY = DESCRIPTOR.message_types_by_name['StackStatQuery']
PublishStackRequest = _reflection.GeneratedProtocolMessageType('PublishStackRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHSTACKREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.PublishStackRequest)
  })
_sym_db.RegisterMessage(PublishStackRequest)

CreateStackRequest = _reflection.GeneratedProtocolMessageType('CreateStackRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTACKREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateStackRequest)
  })
_sym_db.RegisterMessage(CreateStackRequest)

StackRequest = _reflection.GeneratedProtocolMessageType('StackRequest', (_message.Message,), {
  'DESCRIPTOR' : _STACKREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackRequest)
  })
_sym_db.RegisterMessage(StackRequest)

GetStackRequest = _reflection.GeneratedProtocolMessageType('GetStackRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTACKREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.GetStackRequest)
  })
_sym_db.RegisterMessage(GetStackRequest)

UpdateStackRequest = _reflection.GeneratedProtocolMessageType('UpdateStackRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTACKREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateStackRequest)
  })
_sym_db.RegisterMessage(UpdateStackRequest)

StackInfo = _reflection.GeneratedProtocolMessageType('StackInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackInfo)
  })
_sym_db.RegisterMessage(StackInfo)

StacksInfo = _reflection.GeneratedProtocolMessageType('StacksInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKSINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StacksInfo)
  })
_sym_db.RegisterMessage(StacksInfo)

StackQuery = _reflection.GeneratedProtocolMessageType('StackQuery', (_message.Message,), {
  'DESCRIPTOR' : _STACKQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackQuery)
  })
_sym_db.RegisterMessage(StackQuery)

StackStatQuery = _reflection.GeneratedProtocolMessageType('StackStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _STACKSTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.stack_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackStatQuery)
  })
_sym_db.RegisterMessage(StackStatQuery)

_STACK = DESCRIPTOR.services_by_name['Stack']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STACK.methods_by_name['create_stack']._options = None
  _STACK.methods_by_name['create_stack']._serialized_options = b'\202\323\344\223\002\030\"\026/provisioning/v1/stack'
  _STACK.methods_by_name['get_stacks']._options = None
  _STACK.methods_by_name['get_stacks']._serialized_options = b'\202\323\344\223\002;\022\027/provisioning/v1/stacksZ \"\036/provisioning/v1/stacks/search'
  _STACK.methods_by_name['get_stack']._options = None
  _STACK.methods_by_name['get_stack']._serialized_options = b'\202\323\344\223\002#\022!/provisioning/v1/stack/{stack_id}'
  _STACK.methods_by_name['update_stack']._options = None
  _STACK.methods_by_name['update_stack']._serialized_options = b'\202\323\344\223\002\030\032\026/provisioning/v1/stack'
  _STACK.methods_by_name['delete_stack']._options = None
  _STACK.methods_by_name['delete_stack']._serialized_options = b'\202\323\344\223\002#*!/provisioning/v1/stack/{stack_id}'
  _STACK.methods_by_name['publish_stack']._options = None
  _STACK.methods_by_name['publish_stack']._serialized_options = b'\202\323\344\223\002 \"\036/provisioning/v1/stack/publish'
  _STACK.methods_by_name['stat']._options = None
  _STACK.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\035\"\033/provisioning/v1/stack/stat'
  _STACK.methods_by_name['plan_stack']._options = None
  _STACK.methods_by_name['plan_stack']._serialized_options = b'\202\323\344\223\002\035\"\033/provisioning/v1/stack/plan'
  _PUBLISHSTACKREQUEST._serialized_start=295
  _PUBLISHSTACKREQUEST._serialized_end=476
  _CREATESTACKREQUEST._serialized_start=479
  _CREATESTACKREQUEST._serialized_end=745
  _STACKREQUEST._serialized_start=747
  _STACKREQUEST._serialized_end=798
  _GETSTACKREQUEST._serialized_start=800
  _GETSTACKREQUEST._serialized_end=888
  _UPDATESTACKREQUEST._serialized_start=891
  _UPDATESTACKREQUEST._serialized_end=1335
  _STACKINFO._serialized_start=1338
  _STACKINFO._serialized_end=1989
  _STACKSINFO._serialized_start=1991
  _STACKSINFO._serialized_end=2082
  _STACKQUERY._serialized_start=2085
  _STACKQUERY._serialized_end=2254
  _STACKSTATQUERY._serialized_start=2256
  _STACKSTATQUERY._serialized_end=2345
  _STACK._serialized_start=2348
  _STACK._serialized_end=3448
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#spaceone/api/identity/v1/user.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xa0\x02\n\x11\x43reateUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x35\n\tuser_type\x18\x05 \x01(\x0e\x32\".spaceone.api.identity.v1.UserType\x12\x36\n\x07\x62\x61\x63kend\x18\x06 \x01(\x0e\x32%.spaceone.api.identity.v1.UserBackend\x12\x10\n\x08language\x18\x07 \x01(\t\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12%\n\x04tags\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\n \x01(\t\"\xc7\x01\n\x11UpdateUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x14\n\x0cold_password\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\r\n\x05\x65mail\x18\x05 \x01(\t\x12\x10\n\x08language\x18\x06 \x01(\t\x12\x10\n\x08timezone\x18\x07 \x01(\t\x12%\n\x04tags\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\n \x01(\t\"~\n\x19SetRequiredActionsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12=\n\x07\x61\x63tions\x18\x02 \x03(\x0e\x32,.spaceone.api.identity.v1.UserRequiredAction\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"1\n\x0bUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"B\n\x0eGetUserRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xf6\x01\n\tUserQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\r\n\x05\x65mail\x18\x05 \x01(\t\x12\x35\n\tuser_type\x18\x06 \x01(\x0e\x32\".spaceone.api.identity.v1.UserType\x12\x36\n\x07\x62\x61\x63kend\x18\x07 \x01(\x0e\x32%.spaceone.api.identity.v1.UserBackend\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xef\x03\n\x08UserInfo\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x37\n\x05state\x18\x03 \x01(\x0e\x32(.spaceone.api.identity.v1.UserInfo.State\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x35\n\tuser_type\x18\x05 \x01(\x0e\x32\".spaceone.api.identity.v1.UserType\x12\x36\n\x07\x62\x61\x63kend\x18\x06 \x01(\x0e\x32%.spaceone.api.identity.v1.UserBackend\x12\x10\n\x08language\x18\x07 \x01(\t\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12\x46\n\x10required_actions\x18\t \x03(\x0e\x32,.spaceone.api.identity.v1.UserRequiredAction\x12%\n\x04tags\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x18\n\x10last_accessed_at\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\"9\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x12\x0b\n\x07PENDING\x10\x03\"U\n\tUsersInfo\x12\x33\n\x07results\x18\x01 \x03(\x0b\x32\".spaceone.api.identity.v1.UserInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"X\n\rUserStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"F\n\x0e\x46indUserSearch\x12\x11\n\x07user_id\x18\x01 \x01(\tH\x00\x12\x11\n\x07keyword\x18\x02 \x01(\tH\x00\x42\x0e\n\x0csearch_alias\"\\\n\rFindUserQuery\x12\x38\n\x06search\x18\x01 \x01(\x0b\x32(.spaceone.api.identity.v1.FindUserSearch\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"c\n\x0c\x46indUserInfo\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"]\n\rFindUsersInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.identity.v1.FindUserInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05*8\n\x0bUserBackend\x12\x10\n\x0cNONE_BACKEND\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02*6\n\x08UserType\x12\x12\n\x0eNONE_USER_TYPE\x10\x00\x12\x08\n\x04USER\x10\x01\x12\x0c\n\x08\x41PI_USER\x10\x02*K\n\x12UserRequiredAction\x12\x13\n\x0fUPDATE_PASSWORD\x10\x00\x12 \n\x1cPASS_PREVENT_LOGIN_DUPLICATE\x10\x01\x32\xe1\n\n\x04User\x12u\n\x06\x63reate\x12+.spaceone.api.identity.v1.CreateUserRequest\x1a\".spaceone.api.identity.v1.UserInfo\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x12/identity/v1/users\x12u\n\x06update\x12+.spaceone.api.identity.v1.UpdateUserRequest\x1a\".spaceone.api.identity.v1.UserInfo\"\x1a\x82\xd3\xe4\x93\x02\x14\x1a\x12/identity/v1/users\x12\xa0\x01\n\x14set_required_actions\x12\x33.spaceone.api.identity.v1.SetRequiredActionsRequest\x1a\".spaceone.api.identity.v1.UserInfo\"/\x82\xd3\xe4\x93\x02)\"\'/identity/v1/users/set-required-actions\x12\x7f\n\x06\x65nable\x12%.spaceone.api.identity.v1.UserRequest\x1a\".spaceone.api.identity.v1.UserInfo\"*\x82\xd3\xe4\x93\x02$\x1a\"/identity/v1/user/{user_id}/enable\x12\x81\x01\n\x07\x64isable\x12%.spaceone.api.identity.v1.UserRequest\x1a\".spaceone.api.identity.v1.UserInfo\"+\x82\xd3\xe4\x93\x02%\x1a#/identity/v1/user/{user_id}/disable\x12\x63\n\x06\x64\x65lete\x12%.spaceone.api.identity.v1.UserRequest\x1a\x16.google.protobuf.Empty\"\x1a\x82\xd3\xe4\x93\x02\x14*\x12/identity/v1/users\x12x\n\x03get\x12(.spaceone.api.identity.v1.GetUserRequest\x1a\".spaceone.api.identity.v1.UserInfo\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/identity/v1/user/{user_id}\x12\x89\x01\n\x04list\x12#.spaceone.api.identity.v1.UserQuery\x1a#.spaceone.api.identity.v1.UsersInfo\"7\x82\xd3\xe4\x93\x02\x31\x12\x12/identity/v1/usersZ\x1b\"\x19/identity/v1/users/search\x12i\n\x04stat\x12\'.spaceone.api.identity.v1.UserStatQuery\x1a\x17.google.protobuf.Struct\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/identity/v1/users/stat\x12y\n\x04\x66ind\x12\'.spaceone.api.identity.v1.FindUserQuery\x1a\'.spaceone.api.identity.v1.FindUsersInfo\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/identity/v1/users/find\x12r\n\x04sync\x12%.spaceone.api.identity.v1.UserRequest\x1a\".spaceone.api.identity.v1.UserInfo\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/identity/v1/users/syncb\x06proto3')

_USERBACKEND = DESCRIPTOR.enum_types_by_name['UserBackend']
UserBackend = enum_type_wrapper.EnumTypeWrapper(_USERBACKEND)
_USERTYPE = DESCRIPTOR.enum_types_by_name['UserType']
UserType = enum_type_wrapper.EnumTypeWrapper(_USERTYPE)
_USERREQUIREDACTION = DESCRIPTOR.enum_types_by_name['UserRequiredAction']
UserRequiredAction = enum_type_wrapper.EnumTypeWrapper(_USERREQUIREDACTION)
NONE_BACKEND = 0
LOCAL = 1
EXTERNAL = 2
NONE_USER_TYPE = 0
USER = 1
API_USER = 2
UPDATE_PASSWORD = 0
PASS_PREVENT_LOGIN_DUPLICATE = 1


_CREATEUSERREQUEST = DESCRIPTOR.message_types_by_name['CreateUserRequest']
_UPDATEUSERREQUEST = DESCRIPTOR.message_types_by_name['UpdateUserRequest']
_SETREQUIREDACTIONSREQUEST = DESCRIPTOR.message_types_by_name['SetRequiredActionsRequest']
_USERREQUEST = DESCRIPTOR.message_types_by_name['UserRequest']
_GETUSERREQUEST = DESCRIPTOR.message_types_by_name['GetUserRequest']
_USERQUERY = DESCRIPTOR.message_types_by_name['UserQuery']
_USERINFO = DESCRIPTOR.message_types_by_name['UserInfo']
_USERSINFO = DESCRIPTOR.message_types_by_name['UsersInfo']
_USERSTATQUERY = DESCRIPTOR.message_types_by_name['UserStatQuery']
_FINDUSERSEARCH = DESCRIPTOR.message_types_by_name['FindUserSearch']
_FINDUSERQUERY = DESCRIPTOR.message_types_by_name['FindUserQuery']
_FINDUSERINFO = DESCRIPTOR.message_types_by_name['FindUserInfo']
_FINDUSERSINFO = DESCRIPTOR.message_types_by_name['FindUsersInfo']
_USERINFO_STATE = _USERINFO.enum_types_by_name['State']
CreateUserRequest = _reflection.GeneratedProtocolMessageType('CreateUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreateUserRequest)
  })
_sym_db.RegisterMessage(CreateUserRequest)

UpdateUserRequest = _reflection.GeneratedProtocolMessageType('UpdateUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateUserRequest)
  })
_sym_db.RegisterMessage(UpdateUserRequest)

SetRequiredActionsRequest = _reflection.GeneratedProtocolMessageType('SetRequiredActionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETREQUIREDACTIONSREQUEST,
  '__module__' : 'spaceone.api.identity.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.SetRequiredActionsRequest)
  })
_sym_db.RegisterMessage(SetRequiredActionsRequest)

UserRequest = _reflection.GeneratedProtocolMessageType('UserRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UserRequest)
  })
_sym_db.RegisterMessage(UserRequest)

GetUserRequest = _reflection.GeneratedProtocolMessageType('GetUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetUserRequest)
  })
_sym_db.RegisterMessage(GetUserRequest)

UserQuery = _reflection.GeneratedProtocolMessageType('UserQuery', (_message.Message,), {
  'DESCRIPTOR' : _USERQUERY,
  '__module__' : 'spaceone.api.identity.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UserQuery)
  })
_sym_db.RegisterMessage(UserQuery)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERINFO,
  '__module__' : 'spaceone.api.identity.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UserInfo)
  })
_sym_db.RegisterMessage(UserInfo)

UsersInfo = _reflection.GeneratedProtocolMessageType('UsersInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERSINFO,
  '__module__' : 'spaceone.api.identity.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UsersInfo)
  })
_sym_db.RegisterMessage(UsersInfo)

UserStatQuery = _reflection.GeneratedProtocolMessageType('UserStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _USERSTATQUERY,
  '__module__' : 'spaceone.api.identity.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UserStatQuery)
  })
_sym_db.RegisterMessage(UserStatQuery)

FindUserSearch = _reflection.GeneratedProtocolMessageType('FindUserSearch', (_message.Message,), {
  'DESCRIPTOR' : _FINDUSERSEARCH,
  '__module__' : 'spaceone.api.identity.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.FindUserSearch)
  })
_sym_db.RegisterMessage(FindUserSearch)

FindUserQuery = _reflection.GeneratedProtocolMessageType('FindUserQuery', (_message.Message,), {
  'DESCRIPTOR' : _FINDUSERQUERY,
  '__module__' : 'spaceone.api.identity.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.FindUserQuery)
  })
_sym_db.RegisterMessage(FindUserQuery)

FindUserInfo = _reflection.GeneratedProtocolMessageType('FindUserInfo', (_message.Message,), {
  'DESCRIPTOR' : _FINDUSERINFO,
  '__module__' : 'spaceone.api.identity.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.FindUserInfo)
  })
_sym_db.RegisterMessage(FindUserInfo)

FindUsersInfo = _reflection.GeneratedProtocolMessageType('FindUsersInfo', (_message.Message,), {
  'DESCRIPTOR' : _FINDUSERSINFO,
  '__module__' : 'spaceone.api.identity.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.FindUsersInfo)
  })
_sym_db.RegisterMessage(FindUsersInfo)

_USER = DESCRIPTOR.services_by_name['User']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USER.methods_by_name['create']._options = None
  _USER.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\024\"\022/identity/v1/users'
  _USER.methods_by_name['update']._options = None
  _USER.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\024\032\022/identity/v1/users'
  _USER.methods_by_name['set_required_actions']._options = None
  _USER.methods_by_name['set_required_actions']._serialized_options = b'\202\323\344\223\002)\"\'/identity/v1/users/set-required-actions'
  _USER.methods_by_name['enable']._options = None
  _USER.methods_by_name['enable']._serialized_options = b'\202\323\344\223\002$\032\"/identity/v1/user/{user_id}/enable'
  _USER.methods_by_name['disable']._options = None
  _USER.methods_by_name['disable']._serialized_options = b'\202\323\344\223\002%\032#/identity/v1/user/{user_id}/disable'
  _USER.methods_by_name['delete']._options = None
  _USER.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\024*\022/identity/v1/users'
  _USER.methods_by_name['get']._options = None
  _USER.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\035\022\033/identity/v1/user/{user_id}'
  _USER.methods_by_name['list']._options = None
  _USER.methods_by_name['list']._serialized_options = b'\202\323\344\223\0021\022\022/identity/v1/usersZ\033\"\031/identity/v1/users/search'
  _USER.methods_by_name['stat']._options = None
  _USER.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\031\"\027/identity/v1/users/stat'
  _USER.methods_by_name['find']._options = None
  _USER.methods_by_name['find']._serialized_options = b'\202\323\344\223\002\031\"\027/identity/v1/users/find'
  _USER.methods_by_name['sync']._options = None
  _USER.methods_by_name['sync']._serialized_options = b'\202\323\344\223\002\031\"\027/identity/v1/users/sync'
  _USERBACKEND._serialized_start=2214
  _USERBACKEND._serialized_end=2270
  _USERTYPE._serialized_start=2272
  _USERTYPE._serialized_end=2326
  _USERREQUIREDACTION._serialized_start=2328
  _USERREQUIREDACTION._serialized_end=2403
  _CREATEUSERREQUEST._serialized_start=189
  _CREATEUSERREQUEST._serialized_end=477
  _UPDATEUSERREQUEST._serialized_start=480
  _UPDATEUSERREQUEST._serialized_end=679
  _SETREQUIREDACTIONSREQUEST._serialized_start=681
  _SETREQUIREDACTIONSREQUEST._serialized_end=807
  _USERREQUEST._serialized_start=809
  _USERREQUEST._serialized_end=858
  _GETUSERREQUEST._serialized_start=860
  _GETUSERREQUEST._serialized_end=926
  _USERQUERY._serialized_start=929
  _USERQUERY._serialized_end=1175
  _USERINFO._serialized_start=1178
  _USERINFO._serialized_end=1673
  _USERINFO_STATE._serialized_start=1616
  _USERINFO_STATE._serialized_end=1673
  _USERSINFO._serialized_start=1675
  _USERSINFO._serialized_end=1760
  _USERSTATQUERY._serialized_start=1762
  _USERSTATQUERY._serialized_end=1850
  _FINDUSERSEARCH._serialized_start=1852
  _FINDUSERSEARCH._serialized_end=1922
  _FINDUSERQUERY._serialized_start=1924
  _FINDUSERQUERY._serialized_end=2016
  _FINDUSERINFO._serialized_start=2018
  _FINDUSERINFO._serialized_end=2117
  _FINDUSERSINFO._serialized_start=2119
  _FINDUSERSINFO._serialized_end=2212
  _USER._serialized_start=2406
  _USER._serialized_end=3783
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/repository/v1/policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.repository.v1 import repository_pb2 as spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/repository/v1/policy.proto\x12\x1aspaceone.api.repository.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a+spaceone/api/repository/v1/repository.proto\"\xc5\x01\n\x13\x43reatePolicyRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bpermissions\x18\x02 \x03(\t\x12\x11\n\tpolicy_id\x18\x03 \x01(\t\x12*\n\x06labels\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x15 \x01(\t\x12\x11\n\tdomain_id\x18\x16 \x01(\t\"\xb1\x01\n\x13UpdatePolicyRequest\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bpermissions\x18\x03 \x03(\t\x12*\n\x06labels\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"5\n\rPolicyRequest\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"g\n\x1aGetRepositoryPolicyRequest\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x15\n\rrepository_id\x18\x03 \x01(\t\x12\x0c\n\x04only\x18\x04 \x03(\t\"\x84\x02\n\x0bPolicyQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tpolicy_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x15\n\rrepository_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12<\n\x05state\x18\x07 \x01(\x0e\x32-.spaceone.api.repository.v1.PolicyQuery.State\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\x94\x03\n\nPolicyInfo\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12;\n\x05state\x18\x03 \x01(\x0e\x32,.spaceone.api.repository.v1.PolicyInfo.State\x12\x13\n\x0bpermissions\x18\x0b \x03(\t\x12*\n\x06labels\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\x0frepository_info\x18\x15 \x01(\x0b\x32*.spaceone.api.repository.v1.RepositoryInfo\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x11\n\tdomain_id\x18\x17 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\x12\x12\n\nupdated_at\x18  \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\\\n\x0cPoliciesInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.repository.v1.PolicyInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"q\n\x0fPolicyStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x15\n\rrepository_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t2\xb3\x06\n\x06Policy\x12\x82\x01\n\x06\x63reate\x12/.spaceone.api.repository.v1.CreatePolicyRequest\x1a&.spaceone.api.repository.v1.PolicyInfo\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/repository/v1/policies\x12\x89\x01\n\x06update\x12/.spaceone.api.repository.v1.UpdatePolicyRequest\x1a&.spaceone.api.repository.v1.PolicyInfo\"&\x82\xd3\xe4\x93\x02 \x1a\x1e/repository/v1/policy/{policy}\x12s\n\x06\x64\x65lete\x12).spaceone.api.repository.v1.PolicyRequest\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 *\x1e/repository/v1/policy/{policy}\x12\x8f\x01\n\x03get\x12\x36.spaceone.api.repository.v1.GetRepositoryPolicyRequest\x1a&.spaceone.api.repository.v1.PolicyInfo\"(\x82\xd3\xe4\x93\x02\"\x12 /repository/v1/policies/{policy}\x12\x9c\x01\n\x04list\x12\'.spaceone.api.repository.v1.PolicyQuery\x1a(.spaceone.api.repository.v1.PoliciesInfo\"A\x82\xd3\xe4\x93\x02;\x12\x17/repository/v1/policiesZ \"\x1e/repository/v1/policies/search\x12r\n\x04stat\x12+.spaceone.api.repository.v1.PolicyStatQuery\x1a\x17.google.protobuf.Struct\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/repository/v1/policies/statb\x06proto3')



_CREATEPOLICYREQUEST = DESCRIPTOR.message_types_by_name['CreatePolicyRequest']
_UPDATEPOLICYREQUEST = DESCRIPTOR.message_types_by_name['UpdatePolicyRequest']
_POLICYREQUEST = DESCRIPTOR.message_types_by_name['PolicyRequest']
_GETREPOSITORYPOLICYREQUEST = DESCRIPTOR.message_types_by_name['GetRepositoryPolicyRequest']
_POLICYQUERY = DESCRIPTOR.message_types_by_name['PolicyQuery']
_POLICYINFO = DESCRIPTOR.message_types_by_name['PolicyInfo']
_POLICIESINFO = DESCRIPTOR.message_types_by_name['PoliciesInfo']
_POLICYSTATQUERY = DESCRIPTOR.message_types_by_name['PolicyStatQuery']
_POLICYQUERY_STATE = _POLICYQUERY.enum_types_by_name['State']
_POLICYINFO_STATE = _POLICYINFO.enum_types_by_name['State']
CreatePolicyRequest = _reflection.GeneratedProtocolMessageType('CreatePolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPOLICYREQUEST,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.CreatePolicyRequest)
  })
_sym_db.RegisterMessage(CreatePolicyRequest)

UpdatePolicyRequest = _reflection.GeneratedProtocolMessageType('UpdatePolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPOLICYREQUEST,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.UpdatePolicyRequest)
  })
_sym_db.RegisterMessage(UpdatePolicyRequest)

PolicyRequest = _reflection.GeneratedProtocolMessageType('PolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _POLICYREQUEST,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PolicyRequest)
  })
_sym_db.RegisterMessage(PolicyRequest)

GetRepositoryPolicyRequest = _reflection.GeneratedProtocolMessageType('GetRepositoryPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREPOSITORYPOLICYREQUEST,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.GetRepositoryPolicyRequest)
  })
_sym_db.RegisterMessage(GetRepositoryPolicyRequest)

PolicyQuery = _reflection.GeneratedProtocolMessageType('PolicyQuery', (_message.Message,), {
  'DESCRIPTOR' : _POLICYQUERY,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PolicyQuery)
  })
_sym_db.RegisterMessage(PolicyQuery)

PolicyInfo = _reflection.GeneratedProtocolMessageType('PolicyInfo', (_message.Message,), {
  'DESCRIPTOR' : _POLICYINFO,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PolicyInfo)
  })
_sym_db.RegisterMessage(PolicyInfo)

PoliciesInfo = _reflection.GeneratedProtocolMessageType('PoliciesInfo', (_message.Message,), {
  'DESCRIPTOR' : _POLICIESINFO,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PoliciesInfo)
  })
_sym_db.RegisterMessage(PoliciesInfo)

PolicyStatQuery = _reflection.GeneratedProtocolMessageType('PolicyStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _POLICYSTATQUERY,
  '__module__' : 'spaceone.api.repository.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PolicyStatQuery)
  })
_sym_db.RegisterMessage(PolicyStatQuery)

_POLICY = DESCRIPTOR.services_by_name['Policy']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _POLICY.methods_by_name['create']._options = None
  _POLICY.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\031\"\027/repository/v1/policies'
  _POLICY.methods_by_name['update']._options = None
  _POLICY.methods_by_name['update']._serialized_options = b'\202\323\344\223\002 \032\036/repository/v1/policy/{policy}'
  _POLICY.methods_by_name['delete']._options = None
  _POLICY.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002 *\036/repository/v1/policy/{policy}'
  _POLICY.methods_by_name['get']._options = None
  _POLICY.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\"\022 /repository/v1/policies/{policy}'
  _POLICY.methods_by_name['list']._options = None
  _POLICY.methods_by_name['list']._serialized_options = b'\202\323\344\223\002;\022\027/repository/v1/policiesZ \"\036/repository/v1/policies/search'
  _POLICY.methods_by_name['stat']._options = None
  _POLICY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\036\"\034/repository/v1/policies/stat'
  _CREATEPOLICYREQUEST._serialized_start=240
  _CREATEPOLICYREQUEST._serialized_end=437
  _UPDATEPOLICYREQUEST._serialized_start=440
  _UPDATEPOLICYREQUEST._serialized_end=617
  _POLICYREQUEST._serialized_start=619
  _POLICYREQUEST._serialized_end=672
  _GETREPOSITORYPOLICYREQUEST._serialized_start=674
  _GETREPOSITORYPOLICYREQUEST._serialized_end=777
  _POLICYQUERY._serialized_start=780
  _POLICYQUERY._serialized_end=1040
  _POLICYQUERY_STATE._serialized_start=996
  _POLICYQUERY_STATE._serialized_end=1040
  _POLICYINFO._serialized_start=1043
  _POLICYINFO._serialized_end=1447
  _POLICYINFO_STATE._serialized_start=996
  _POLICYINFO_STATE._serialized_end=1040
  _POLICIESINFO._serialized_start=1449
  _POLICIESINFO._serialized_end=1541
  _POLICYSTATQUERY._serialized_start=1543
  _POLICYSTATQUERY._serialized_end=1656
  _POLICY._serialized_start=1659
  _POLICY._serialized_end=2478
# @@protoc_insertion_point(module_scope)
